alpha: Cronbach's Coefficient Alpha

Description Usage Arguments Details Value References Examples

View source: R/alpha.R

Description

Compute the popular Cronbach's coefficient alpha and associated SEM

Usage

1
alpha(x)

Arguments

x

A data frame or matrix containing data with rows as subjects and columns as items

Details

Alpha is one of several estimates of the internal consistency reliability of a test.

Value

Cronbach's coefficient alpha and associated SEM

References

Cronbach, L. J. (1951). Coefficient alpha and the internal structure of tests. Psychometrika, 6, 297-334.

Examples

1
2

liuhuan90123/EMReliability documentation built on Jan. 29, 2022, 1:16 p.m.