Learn R Programming

emreliability (version 1.0.0)

lord_wingersky: Lord-Wingersky Recursive Formula

Description

Compute the raw score distribution for a given theta value using the Lord-Wingersky recursive formula, given item-level probabilities of a correct response.

Usage

lord_wingersky(probs)

Value

A list with:

x

Vector of possible raw scores, from 0 to ni.

probability

Vector of probabilities for each raw score.

Arguments

probs

A numeric vector (or matrix) of probabilities that a given theta value will correctly answer each item. If a matrix is provided, it will be coerced to a numeric vector.