Description Usage Arguments Details Value References Examples
Compute the popular Cronbach's coefficient alpha and associated SEM
1 | alpha(x)
|
x |
A data frame or matrix containing data with rows as subjects and columns as items |
Alpha is one of several estimates of the internal consistency reliability of a test.
Cronbach's coefficient alpha and associated SEM
Cronbach, L. J. (1951). Coefficient alpha and the internal structure of tests. Psychometrika, 6, 297-334.
1 2 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.