csem.binomial: CSEM and CSSEM with Binomial Model

Description Usage Arguments Value Examples

View source: R/csem.binomial.R

Description

Compute the CSEM and CSSEM using binomial model

Usage

1
csem.binomial(ni, ct = NULL)

Arguments

ni

a numeric value indicating the number of items

ct

A data frame or matrix containing conversion table with the first column as raw scores and the second column as scale scores

Value

a list containing raw scores and corresponding CSEM using bimonial model, and CSSEM if the conversion table is provided

Examples

1
2

liuhuan90123/EMReliability documentation built on Jan. 29, 2022, 1:16 p.m.