Description Usage Arguments Value Examples
View source: R/csem.binomial.R
Compute the CSEM and CSSEM using binomial model
1 | csem.binomial(ni, ct = NULL)
|
ni |
a numeric value indicating the number of items |
ct |
A data frame or matrix containing conversion table with the first column as raw scores and the second column as scale scores |
a list containing raw scores and corresponding CSEM using bimonial model, and CSSEM if the conversion table is provided
1 2 | csem.binomial(40)
csem.binomial(40, ct.u)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.