Compute the raw score distribution for a given theta value using the Lord-Wingersky recursive formula, given item-level probabilities of a correct response.
lord_wingersky(probs)A list with:
Vector of possible raw scores, from 0 to ni.
Vector of probabilities for each raw score.
A numeric vector (or matrix) of probabilities that a given theta value will correctly answer each item. If a matrix is provided, it will be coerced to a numeric vector.