powered by
Compute the stratified Feldt's coefficient for a test composed of several item strata (e.g., subtests or subscales).
stratified_feldt(x, s)
A named list with:
Stratified Feldt's coefficient.
A data frame or matrix containing item responses, with rows as subjects and columns as items. Items are assumed to be ordered by stratum.
A numeric vector giving the number of items in each stratum. The sum of s must equal ncol(x).
s
ncol(x)
Stratified Feldt's coefficient is an estimate of internal consistency reliability for a composite test formed by multiple strata.
data(data.m) stratified_feldt(data.m, c(13, 12, 6))
Run the code above in your browser using DataLab